@@ -168,10 +168,19 @@ typedef uint32_t ver_t;
 #define __file__ stringize ( __file_name__ )
 #endif
 
+#if ! defined __file__
+#define __file__ __FILE__
+#endif
+
 #if ! defined __fext__ && defined __file_ext__
 #define __fext__ stringize ( __file_ext__ )
 #endif
 
+#if ! defined __fext__
+#define __fext__ ""
+#endif
+
+
 /*--------------------------------------------------------------------------
  * PKGNAMESTR
  */
@@ -179,18 +188,6 @@ typedef uint32_t ver_t;
 #define PKGNAMESTR stringize ( PKGNAME )
 #endif
 
-/*--------------------------------------------------------------------------
- * memcpy()
- *  as of 11/29/2016 we are prohibiting the use of memcpy
- *  NB - we depend upon including <string.h> BEFORE redefining
- */
-#undef memcpy
-#if _DEBUGGING && LINUX
-#define memcpy "DON'T USE MEMCPY! USE MEMMOVE INSTEAD!!"
-#else
-#define memcpy memmove
-#endif
-
 #ifdef __cplusplus
 }
 #endif
