@@ -250,6 +250,7 @@ rc_t cigar_string_2_0(KDataBuffer *dst,
     int opcode;
     
 #define BUF_WRITE(OP, LEN) { if ((rc = op2b(dst, (unsigned const)(di + boff), &nwrit, (int const)(OP), (unsigned)(LEN))) != 0) return rc; di += nwrit; }
+    assert ( read_start >= 0 );
     si = read_start;
     if ( /* !use_S && */ read_start == read_end && reflen > 0 ) /** full delete as a last ploidy ends up written nowhere  **/
     {
@@ -1595,7 +1596,8 @@ rc_t CC right_soft_clip_5_impl ( void *data, const VXformInfo *info, int64_t row
         
         for (n = 0; n < nreads; ++n) {
             unsigned const len = read_len[n];
-            unsigned clip = 0;
+            unsigned last = 0;
+            unsigned prev = 0;
             unsigned j;
             
             for (j = 0; j < len; ++j, ++cur) {
@@ -1605,12 +1607,12 @@ rc_t CC right_soft_clip_5_impl ( void *data, const VXformInfo *info, int64_t row
                     
                     ++cur_ro;
                     if (j > 0 && offset < 0 && type == 1) {
-                        assert(clip == 0);
-                        clip = -offset;
+                        prev = last;
+                        last = -offset;
                     }
                 }
             }
-            result[n] = clip;
+            result[n] = prev == 0 ? last : prev;
         }
     }
     
