@@ -76,13 +76,14 @@ static VPath *makePath(VDBManager const *mgr, unsigned length, char const *acces
     return result;
 }
 
-static String const *getContainer(VTable const *const forTable)
+static String const *getContainer(VTable const *const forTable,
+    const String ** path)
 {
     VDatabase const *db = NULL;
     rc_t rc = VTableOpenParentRead(forTable, &db);
     if (rc == 0) {
         String const *container = NULL;
-        rc = VDatabaseGetAccession(db, &container);
+        rc = VDatabaseGetAccession(db, &container, path);
         VDatabaseRelease(db);
         if (rc == 0)
             return container;
@@ -94,9 +95,11 @@ static VPath const *getURL(VDBManager const *mgr, unsigned length, char const *a
 {
     VPath * const result = makePath(mgr, length, accession);
     if (result) {
-        String const * const container = getContainer(forTable);
-        rc_t const rc = VPathSetAccOfParentDb(result, container);
+        String const * path = NULL;
+        String const * const container = getContainer(forTable, &path);
+        rc_t const rc = VPathSetAccOfParentDb(result, container, path);
         StringWhack(container);
+        StringWhack(path);
         if (rc == 0)
             return result;
         VPathRelease(result);
@@ -325,6 +328,7 @@ static void RestoreReadSharedFree(RestoreReadShared *const self)
     KRWLockRelease(self->rwl);
     KRefcountWhack(&self->refcount, "RestoreReadShared");
     free(self);
+    LOGMSG(klogDebug, "Released shared global RestoreRead data object");
 }
 
 static void RestoreReadSharedRelease(RestoreReadShared *const self)
@@ -361,6 +365,31 @@ static RestoreReadShared *getRestoreReadShared(rc_t *const prc)
     return g_shared.ptr;
 }
 
+unsigned RestoreReadShared_getState(unsigned *refSeqs, unsigned *wgs, unsigned *errors, unsigned *activeRefSeqs)
+{
+    if (g_shared.ptr) {
+        rc_t rc = 0;
+        RestoreReadShared *const ptr = getRestoreReadShared(&rc);
+
+        RestoreReadSharedReader(ptr);
+        *refSeqs = ptr->refSeqs.entries;
+        *wgs = ptr->wgs.entries;
+        *errors = ptr->errors.entries;
+        *activeRefSeqs = 0;
+        {
+            unsigned i;
+            for (i = 0; i < *refSeqs; ++i) {
+                if (ptr->refSeqs.entry[i].object->async != NULL)
+                    ++*activeRefSeqs;
+            }
+        }
+        RestoreReadSharedReaderDone(ptr);
+        RestoreReadSharedRelease(ptr);
+        return 1;
+    }
+    else return 0;
+}
+
 struct RestoreRead {
     VDBManager const *mgr;
     RestoreReadShared *shared;
