@@ -52,7 +52,7 @@ struct AWS;
 
 #include "aws-priv.h" /* AWSDoAuthentication */
 #include "cloud-cmn.h" /* KNSManager_Read */
-#include "cloud-priv.h"
+#include "cloud-priv.h" /* CloudGetCachedComputeEnvironmentToken */
 
 static rc_t PopulateCredentials ( AWS * self );
 
@@ -87,9 +87,9 @@ static char const *envCE()
     static bool firstTime = true;
     char const *const env = firstTime ? getenv(ENV_MAGIC_CE_TOKEN) : NULL;
     firstTime = false;
-    if (env != NULL)
-        DBGMSG(DBG_VFS, DBG_FLAG(DBG_VFS_PATH),
-               ("Got location from environment\n"));
+    if ( env != NULL && *env != 0 )
+        DBGMSG(DBG_VFS, DBG_FLAG(DBG_VFS_CE),
+               ("Got AWS location from environment\n"));
     return env;
 }
 
@@ -102,8 +102,8 @@ static rc_t readCE(AWS const *const self, size_t size, char location[])
     char pkcs7[4096] = "";
     rc_t rc;
     
-    DBGMSG(DBG_VFS, DBG_FLAG(DBG_VFS_PATH),
-           ("Reading location from provider\n"));
+    DBGMSG(DBG_VFS, DBG_FLAG(DBG_VFS_CE),
+           ("Reading AWS location from provider\n"));
     rc = KNSManager_Read(self->dad.kns, document, sizeof document,
                  "http://169.254.169.254/latest/dynamic/instance-identity/document",
                  NULL, NULL);
@@ -131,11 +131,19 @@ rc_t CC AWSMakeComputeEnvironmentToken ( const AWS * self, const String ** ce_to
     else {
         char const *const env = envCE();
         char location[4096] = "";
-        rc_t const rc = env == NULL ? readCE(self, sizeof(location), location) : 0;
+        rc_t rc = 0;
+        if (CloudGetCachedComputeEnvironmentToken(&self->dad, ce_token))
+            return 0;
+        rc = env == NULL ? readCE(self, sizeof(location), location) : 0;
         if (rc == 0) {
             String s;
             StringInitCString(&s, env != NULL ? env : location);
-            return StringCopy(ce_token, &s);
+            rc = StringCopy(ce_token, &s);
+            if (rc == 0) { /* ignore rc below */
+                assert(ce_token);
+                CloudSetCachedComputeEnvironmentToken(&self->dad, *ce_token);
+            }
+            return rc;
         }
         return rc;
     }
@@ -245,8 +253,8 @@ LIB_EXPORT rc_t CC CloudMgrMakeAWS ( const CloudMgr * self, AWS ** p_aws )
                 &user_agrees_to_reveal_instance_identity);
         }
 
-        rc = CloudInit ( & aws -> dad, ( const Cloud_vt * ) & AWS_vt_v1, "AWS", self -> kns, user_agrees_to_pay,
-            user_agrees_to_reveal_instance_identity );
+        rc = CloudInit ( & aws -> dad, ( const Cloud_vt * ) & AWS_vt_v1, "AWS",
+            self, user_agrees_to_pay, user_agrees_to_reveal_instance_identity );
         if ( rc == 0 )
         {
             rc = PopulateCredentials( aws );
@@ -505,7 +513,7 @@ static void make_home_node ( char *path, size_t path_size )
         if ( home_node == NULL ) {
             /* just grab the HOME env variable */
             home = getenv ( "HOME" );
-            if ( home != NULL ) {
+            if ( home != NULL && *home != 0 ) {
                 num_read = string_copy_measure ( path, path_size, home );
                 if ( num_read >= path_size ) path[0] = 0;
             }
@@ -514,7 +522,7 @@ static void make_home_node ( char *path, size_t path_size )
             rc = KConfigNodeRead ( home_node, 0, path, path_size, &num_read, NULL );
             if ( rc != 0 ) {
                 home = getenv ( "HOME" );
-                if ( home != NULL ) {
+                if ( home != NULL && *home != 0 ) {
                     num_read = string_copy_measure ( path, path_size, home );
                     if ( num_read >= path_size ) path[0] = 0;
                 }
@@ -536,7 +544,7 @@ static rc_t LoadCredentials ( AWS * self  )
     rc_t rc = KDirectoryNativeDir ( &wd );
     if ( rc ) return rc;
 
-    if ( conf_env ) 
+    if ( conf_env && *conf_env != 0 ) 
     {
         const KFile *cred_file = NULL;
         rc = KDirectoryOpenFileRead ( wd, &cred_file, "%s", conf_env );
@@ -549,7 +557,7 @@ static rc_t LoadCredentials ( AWS * self  )
         return rc;
     }
 
-    if ( cred_env ) 
+    if ( cred_env && *cred_env != 0 ) 
     {
         const KFile *cred_file = NULL;
         rc = KDirectoryOpenFileRead ( wd, &cred_file, "%s", cred_env );
@@ -614,7 +622,7 @@ rc_t PopulateCredentials ( AWS * self )
     }
 
     /* Get Profile */
-    if ( profile != NULL )
+    if ( profile != NULL && *profile != 0 )
     {
         self -> profile = string_dup ( profile, string_size ( profile ) );
     }
@@ -650,11 +658,11 @@ rc_t PopulateCredentials ( AWS * self )
 
     /* Check AWS_CONFIG_FILE and AWS_SHARED_CREDENTIAL_FILE, if specified check for credentials and/or profile name */
     const char *conf_env = getenv ( "AWS_CONFIG_FILE" );
-    if ( conf_env == NULL )
+    if ( conf_env == NULL || *conf_env == 0 )
     {
         conf_env = getenv ( "AWS_SHARED_CREDENTIAL_FILE" );
     }
-    if ( conf_env )
+    if ( conf_env && *conf_env != 0 )
     {
         KDirectory *wd = NULL;
         const KFile *cred_file = NULL;
