@@ -91,12 +91,33 @@ bool CC is_valid_name (const char * string)
  */
 typedef void * ParamValueP;
 
-typedef struct ParamValueContainer {
+typedef struct ParamValueContainer ParamValueContainer;
+struct ParamValueContainer {
     uint32_t        param_index;
     ParamValueP     param_value;
     ConvertParamFnP convert_fn;
     WhackParamFnP   whack;
-} ParamValueContainer;
+};
+
+typedef struct Parameter Parameter;
+struct Parameter {
+    uint32_t position;
+    ConvertParamFnP  convert_fn;
+};
+
+struct Args
+{
+    BSTree names;
+    BSTree aliases;
+    Vector params;
+    Vector argv;
+    Vector param_values;
+    Vector help;
+#if HONOR_LEGACY_Q_ALIAS
+    bool   qalias_replaced;
+#endif
+};
+
 
 /*
  * Whack
@@ -106,7 +127,7 @@ static
 void CC ParamValueNotConvWhack (void * self)
 {
     assert (self); /* not an absolute requirement but if NULL we got programming error */
-    
+
     free (self);
 }
 
@@ -115,11 +136,11 @@ void CC ParamValueVectorWhack (void * self, void * ignored)
 {
     ParamValueContainer * p_container;
     assert (self);
-    
+
     p_container = (ParamValueContainer *)self;
     if (p_container->whack)
         p_container->whack(p_container->param_value);
-    
+
     free (self);
 }
 
@@ -132,17 +153,17 @@ static
 rc_t CC ParamValueMake (ParamValueContainer * p_container, uint32_t arg_index, const char * value, size_t value_size, ConvertParamFnP convert_fn)
 {
     size_t alloc_size;
-    
+
     assert (p_container);
     assert (value);
-    
+
     if (value_size == 0)
         return RC ( rcExe, rcArgv, rcConstructing, rcParam, rcEmpty );
 
     p_container->param_index = arg_index;
     p_container->whack = ParamValueNotConvWhack;
     p_container->convert_fn = convert_fn;
-    
+
     alloc_size = value_size + 1;
     p_container->param_value = malloc (alloc_size);
 
@@ -172,7 +193,7 @@ typedef struct Option
     uint32_t    count;          /* count of times option seen on the command line */
     uint32_t    max_count;      /* if non-zero, how many times is it legal to be seen */
     bool        needs_value;    /* does this option take/require a value? */
-    bool        required;       
+    bool        required;
     bool        deprecated;     /* a warning if used */
     bool        error;          /* an error if used */
     bool        called_by_alias;/* short name was used for this option */
@@ -197,7 +218,7 @@ rc_t CC OptionMake (Option ** pself, const char * name, size_t size, uint32_t ma
         rc = RC (rcExe, rcArgv, rcConstructing, rcMemory, rcExhausted);
         PLOGERR (klogErr, (klogErr, rc, "Error adding option '$(O)'","O=--%s",name));
     }
-    else 
+    else
     {
         if ((self->needs_value = needs_value) != false)
             VectorInit (&self->values,0,4);
@@ -266,7 +287,7 @@ uint32_t CC OptionGetCount (const Option *self)
     return self->count;
 }
 
-/* 
+/*
  * GetValue
  *    returns the address of the Nth value (not a copy of the value)
  */
@@ -274,7 +295,7 @@ static
 rc_t CC OptionGetValue (const Option * self, uint32_t number, const void ** value)
 {
     ParamValueContainer * p_container;
-    /* SKH -- not sure why this was here. 
+    /* SKH -- not sure why this was here.
        const char * pc; */
     /* uint32_t count; */
 
@@ -287,9 +308,9 @@ rc_t CC OptionGetValue (const Option * self, uint32_t number, const void ** valu
     /* SKH -- this was checking pc, which is uninitialized */
     if (p_container == NULL)
         return RC (rcExe, rcArgv, rcAccessing, rcIndex, rcExcessive);
-    
+
     *value = p_container->param_value;
-    
+
     return 0;
 }
 
@@ -302,7 +323,7 @@ rc_t CC OptionAddValue (Option * option, uint32_t arg_index, const char * value,
     rc_t rc = 0;
 
     assert (option);
-    
+
     ++option->count;
 
 /*     KOutMsg ("%s: name %s count %u max_count %u value %s\n", __func__, option->name, option->count, option->max_count, value); */
@@ -336,7 +357,7 @@ rc_t CC OptionAddValue (Option * option, uint32_t arg_index, const char * value,
         rc = ParamValueMake (p_container, arg_index, value, size, option->convert_fn);
         if (rc == 0)
         {
-            /* NOTE: effectively going in as a char ** though we will 
+            /* NOTE: effectively going in as a char ** though we will
              * pull it out as a char* with the same value */
             rc = VectorAppend (&option->values, NULL, p_container);
             if (rc)
@@ -415,7 +436,7 @@ rc_t CC OptAliasMake (OptAlias ** pself, const char * name, size_t size,
     {
         rc_t rc = RC (rcExe, rcArgv, rcConstructing, rcMemory, rcExhausted);
         PLOGERR (klogErr,
-                 (klogErr, rc, "Error creating structure for alias '$(A)' for parameter '$(B)", 
+                 (klogErr, rc, "Error creating structure for alias '$(A)' for parameter '$(B)",
                   "A=%s,B=%s", name, option->name));
         *pself = NULL;
         return rc;
@@ -443,17 +464,6 @@ void CC OptAliasTreeWhack (BSTNode * node, void * ignored)
     OptAliasWhack ((OptAlias*)node);
 }
 
-#if 0
-static
-const char * CC OptAliasName (const OptAlias * self, size_t * size)
-{
-    assert (self);
-
-    if (size)
-        *size = self->size;
-    return self->name;
-}
-#endif
 static
 Option * CC OptAliasOption (const OptAlias *self)
 {
@@ -492,130 +502,11 @@ int64_t CC OptAliasSort (const BSTNode * item, const BSTNode * n)
     return string_cmp (l->name, l->size, r->name, r->size, (uint32_t)( l->size + r->size ) );
 }
 
-#if NOT_USED_YET
-static
-rc_t CC OptDefMakeCopy (OptDef ** pself, OptDef * original)
-{
-    OptDef * self;
-    size_t nsize;
-    size_t asize;
-    size_t hsize;
-
-    nsize = string_size (original->name);
-    asize = original->aliases ? string_size (original->aliases) : 0;
-    hsize = original->help ? string_size (original->help) : 0;
-
-    self = malloc (sizeof (*self) + nsize + 1 + asize + 1 + hsize + 1);
-    if (self == NULL)
-    {
-        rc_t rc;
-        /* assuming DebugMsg is stderr equivalent */
-        rc = RC (rcExe, rcArgv, rcConstructing, rcMemory, rcExhausted);
-        LOGERR (klogFatal, rc, "error creating help for option");
-        return rc;
-    }
-    self->name = (char*)(self+1);
-    string_copy (self->name, nsize + 1, original->name, nsize);
-    self->aliases = self->name + nsize + 1;
-    if (original->aliases)
-    {
-        string_copy (self->aliases, asize + 1, original->aliases, asize);
-    }
-    else
-        self->aliases[0] = '\0';
-    self->help = self->aliases + asize + 1;
-    if (original->help)
-    {
-        string_copy (self->help, hsize + 1, original->help, asize);
-    }
-    else
-        self->help[0] = '\0';
-    self->max_count = original->max_count;
-    self->needs_value = original->needs_value;
-    *pself = self;
-    return 0;
-}
-static
-void CC OptDefCopyVectorWhack (void * self, void * ignored)
-{
-    free (self);
-}
-
-#endif
-
-#if NOT_USED_YET
-
-typedef struct HelpGroup
-{
-    rc_t ( CC * header_fmt) (Args * args, const char * header);
-    Vector options;
-    const char header[1];
-} HelpGroup;
-
-
-static
-rc_t CC HelpGroupMake (HelpGroup ** pself, const char * name)
-{
-    HelpGroup * self;
-    size_t size;
-
-    size = string_size (name);
-    self = malloc (sizeof (*self) + size);
-    if (self == NULL)
-    {
-        fprintf (stderr, "Error allocating help group structure %s\n", name);
-        return RC (rcExe, rcArgv, rcConstructing, rcMemory, rcExhausted);
-    }
-    string_copy (self->name, size+1, name, size);
-    VectorInit (&self->optdefs, 0, 16);
-
-    *pself = self;
-    return 0;
-}
-
-
-static
-rc_t CC HelpGroupAddOptDef (HelpGroup * self, OptDef * option)
-{
-    OptDef * opt;
-    rc_t rc;
-
-    rc = OptDefCopy (&opt, option);
-    if (rc)
-        return rc;
-
-    rc = VectorAppend (&self->optdefs, NULL, opt);
-    if (rc)
-    {
-        fprintf (stderr, "Error appending option for help\n");
-        OptDefCopyVectorWhack (opt, NULL);
-        return rc;
-    }
-    return 0;
-}
-
-static
-void CC HelpGroupVectorWhack (void * item, void * ignored)
-{
-    HelpGroup * self = item;
-
-    assert (self);
-    VectorWhack (&self->optdefs, OptDefCopyVectorWhack, NULL);
-    free (self);
-}
-#endif
-
-typedef struct Parameter
-{
-    uint32_t position;
-    ConvertParamFnP  convert_fn;
-} Parameter;
-
 static
 rc_t CC ParamMake (Parameter ** p_parameter, uint32_t position, ConvertParamFnP convert_fn)
 {
     Parameter * parameter;
-    
+
     parameter = malloc (sizeof(Parameter));
     if (parameter == NULL)
     {
@@ -623,10 +514,10 @@ rc_t CC ParamMake (Parameter ** p_parameter, uint32_t position, ConvertParamFnP
         return RC (rcExe, rcArgv, rcConstructing, rcMemory, rcExhausted);
 
     }
-    
+
     parameter->position = position;
     parameter->convert_fn = convert_fn;
-    
+
     *p_parameter = parameter;
     return 0;
 }
@@ -648,16 +539,16 @@ static
 rc_t CC ParamGetValue (const Vector * param_values, uint32_t number, const void ** value)
 {
     ParamValueContainer * p_container;
-    
+
     assert (param_values);
     assert (value);
-    
+
     p_container = VectorGet (param_values, number);
     if (p_container == NULL)
         return RC (rcExe, rcArgv, rcAccessing, rcIndex, rcExcessive);
-    
+
     *value = p_container->param_value;
-    
+
     return 0;
 }
 
@@ -669,9 +560,9 @@ rc_t CC ParamAddValue (Vector * param_values, uint32_t arg_index, const char * v
 {
     ParamValueContainer * p_container;
     rc_t rc = 0;
-    
+
     assert (param_values);
-    
+
     p_container = (ParamValueContainer *)malloc( sizeof *p_container );
     if (p_container == NULL)
     {
@@ -686,7 +577,7 @@ rc_t CC ParamAddValue (Vector * param_values, uint32_t arg_index, const char * v
         rc = RC (rcExe, rcArgv, rcConstructing, rcParam, rcEmpty);
         return rc;
     }
-    
+
     rc = ParamValueMake (p_container, arg_index, value, size, convert_fn);
     if (rc == 0)
     {
@@ -707,42 +598,134 @@ rc_t CC ParamAddValue (Vector * param_values, uint32_t arg_index, const char * v
     return rc;
 }
 
+static FILE *dumpOptionDefs = NULL;
 
-/* ==========
+/**
+ Print one option definition.
+
+ @param def the definition.
  */
-struct Args
+static void printOptionDefinition(OptDef const *const def)
 {
-    BSTree names;
-    BSTree aliases;
-    Vector params;
-    Vector argv;
-    Vector param_values;
-    Vector help;
-#if NOT_USED_YET
-    HelpGroup * def_help;
-#endif
-#if HONOR_LEGACY_Q_ALIAS
-    bool   qalias_replaced;
-#endif
-};
+    if (dumpOptionDefs) {
+        char const *const no_help[] = {NULL};
+        char const *const aliases = def->aliases ? def->aliases : "";
+        char const *const *const help = def->help ? def->help : no_help;
+        int i;
+        char buffer[4] = "\\\0\0\0";
 
-rc_t CC ArgsMake (Args ** pself)
+        fprintf(dumpOptionDefs, "    TOOL_ARG(\"%s\", \"%s\", %s, TOOL_HELP(", def->name, aliases, def->needs_value ? "true" : "false");
+        for (i = 0; help[i]; ++i) {
+            char const *helptext = help[i];
+            if (helptext[0]) {
+                int j;
+
+                fprintf(dumpOptionDefs, "\"");
+                for (j = 0; helptext[j]; ++j) {
+                    int const ch = helptext[j];
+                    char const *const out = (ch == '\\' || ch == '"') ? buffer : (buffer + 1);
+
+                    buffer[1] = ch;
+                    buffer[2] = '\0';
+                    fprintf(dumpOptionDefs, "%s", out);
+                }
+                fprintf(dumpOptionDefs, "\", ");
+            }
+        }
+        fprintf(dumpOptionDefs, "0)), \\\n");
+    }
+}
+
+static char const *base_name(char const *fullpath, size_t *outsize)
 {
-    rc_t rc;
-    Args * self;
+    char const *result = fullpath;
+
+    for ( ; ; ) {
+        int const ch = *fullpath++;
+        if (ch == '\0') {
+            *outsize = (fullpath - result) - 1;
+            return result;
+        }
+        if (ch == '/')
+            result = fullpath;
+    }
+}
+
+static bool cleaned(unsigned const max, char *result, char const *name)
+{
+    char *const endp = result + max;
+    while (result != endp) {
+        int const ch = *name++;
+        if (ch == '\0') {
+            *result = '\0';
+            return true;
+        }
+        *result++ = isalnum(ch) ? toupper(ch) : '_';
+    }
+    assert(!"not enough space in result string!!!");
+    return false;
+}
+
+/**
+ Open the option definitions file and write tool header information.
+
+ The filename is taken from ${SRATOOLS_DUMP_OPTIONS}.
+ The file is opened in append mode.
+
+ @param argv0 argv[0].
+
+ Example output:
+ @code
+ #define TOOL_ARGS_VDB_DUMP TOOL_ARGS ( \
+     TOOL_ARG("columns", "C", true, TOOL_HELP("columns (default = all)")), \
+     TOOL_ARG("row_id_on", "I", false, TOOL_HELP("print row id")),\
+     TOOL_ARG(0, 0, 0, TOOL_HELP(0)))
+ @endcode
+ */
+static void openOptionDefs(char const *argv0) {
+#if UNIX && _DEBUGGING
+    char const *const enval = getenv("SRATOOLS_DUMP_OPTIONS");
+    if (enval) {
+        size_t basesize = 0;
+        char const *const base = base_name(argv0, &basesize);
+        char toolname[256]; /**< a cleaned-up version of the tool name */
+
+        assert(basesize == strlen(base));
+        assert(basesize < sizeof(toolname));
+        cleaned(sizeof(toolname), toolname, base);
+
+        dumpOptionDefs = strcmp(enval, "-") ? fopen(enval, "a") : stdout;
+        fprintf(dumpOptionDefs, "#define TOOL_NAME_%s \"%s\" /* from argv[0] */\n", toolname, base);
+        fprintf(dumpOptionDefs, "#define TOOL_ARGS_%s TOOL_ARGS ( \\\n", toolname);
+    }
+#endif
+}
+
+/**
+ Close the option definitions file.
+
+ If the file had been opened, this function does not return.
+ */
+static void closeOptionDefs(void) {
+    if (dumpOptionDefs) {
+        fprintf(dumpOptionDefs, "    TOOL_ARG(0, 0, 0, TOOL_HELP(0)))\n\n");
+        fclose(dumpOptionDefs);
+        exit(0);
+    }
+}
+
+static rc_t ArgsMake_int(Args ** pself, char const *const argv0)
+{
+    rc_t rc = 0;
+    Args *self = NULL;
 
     assert (pself);
 
+    if (argv0)
+        openOptionDefs(argv0);
+
     self = malloc (sizeof (*self));
-    if (self == NULL)
-    {
-        rc = RC (rcExe, rcArgv, rcConstructing, rcMemory, rcExhausted);
-    }
-    else
-    {
-#if NOT_USED_YET
-        HelpGroup * help;
-#endif
+    if (self != NULL) {
         BSTreeInit (&self->names);
         BSTreeInit (&self->aliases);
         VectorInit (&self->params,0,8);
@@ -752,44 +735,40 @@ rc_t CC ArgsMake (Args ** pself)
 #if HONOR_LEGACY_Q_ALIAS
         self -> qalias_replaced = false;
 #endif
-#if NOT_USED_YET
-        rc = HelpGroupMake (&help, "NCBI Options");
-        if (rc)
-        {
-            ArgsWhack (self);
-        }
-        else
-        {
-            self->def_help = help;
-            rc = VectorAppend (&self->help, NULL, help);
-        }
-#else
-        rc = 0;
-#endif
+    }
+    else {
+        assert(self != NULL);
+        rc = RC (rcExe, rcArgv, rcConstructing, rcMemory, rcExhausted);
     }
     *pself = (rc == 0) ? self : NULL;
     return rc;
 }
 
-rc_t CC ArgsWhack (Args * self)
+rc_t CC ArgsMake (Args ** pself)
 {
-    if (self)
-    {
+    return ArgsMake_int(pself, NULL);
+}
+
+rc_t CC ArgsWhack (Args * self) {
+    if (self) {
         BSTreeWhack (&self->names, OptionTreeWhack, NULL);
         BSTreeWhack (&self->aliases, OptAliasTreeWhack, NULL);
         VectorWhack (&self->params, ParamVectorWhack, NULL);
         VectorWhack (&self->argv, ParamValueVectorWhack, NULL);
         VectorWhack (&self->param_values, ParamValueVectorWhack, NULL);
-#if NOT_USED_YET
-        VectorWhack (&self->help, HelpGroupVectorWhack, NULL);
-#endif
         free (self);
     }
     return 0;
 }
 
+static rc_t ArgsAddOption_int(Args *const self, bool isStandardOption, const OptDef * option);
 
 rc_t CC ArgsAddOption (Args * self, const OptDef * option)
+{
+    return ArgsAddOption_int(self, false, option);
+}
+
+static rc_t ArgsAddOption_int(Args *const self, bool isStandardOption, const OptDef *const option)
 {
     rc_t rc = 0;
     Option * node;
@@ -816,6 +795,8 @@ rc_t CC ArgsAddOption (Args * self, const OptDef * option)
         PLOGERR (klogInt, (klogInt, rc, "Error using illegal option name '$(O)'", "O=--%s", name));
         return rc;
     }
+    if (!isStandardOption)
+        printOptionDefinition(option);
     size = string_size (name);
     rc = OptionMake (&node, name, size, option->max_count, option->needs_value, option->required, option->convert_fn);
     if (rc)
@@ -954,64 +935,45 @@ rc_t CC ArgsAddLongOption ( Args * self, const char * opt_short_names, const cha
     return ArgsAddOption ( self, & opt );
 }
 
-rc_t CC ArgsAddOptionArray (Args * self, const OptDef * option, uint32_t count
+rc_t CC ArgsAddOptionArray_int(Args * self, bool areStandardOptions, uint32_t count, const OptDef * options
     /*, rc_t (*header_fmt)(Args * args, const char * header), const char * header */ )
 {
     rc_t rc;
-#if NOT_USED_YET
-    HelpGroup * hg;
 
-    rc = HelpGroupMake (&hg, header, header_fmt, option, count);
-    if (rc == 0)
+    for (rc = 0; (rc == 0) && (count > 0); --count, ++options)
     {
-
-        rc = VectorAppend (&self->help, NULL, hg);
-        if (rc == 0)
-        {
-
-            /* count might be zero for help only sections */
-            for (rc = 0; count > 0; --count, ++option)
-            {
-                rc = ArgsAddOption (self, option);
-                if (rc)
-                    break;
-            }
-            if (rc == 0)
-                return 0;
-        }
-        else
-            HelpGroupVectorWhack (hg, NULL);
+        rc = ArgsAddOption_int (self, areStandardOptions, options);
     }
-#else
-    for (rc = 0; (rc == 0) && (count > 0); --count, ++option)
-    {
-        rc = ArgsAddOption (self, option);
-    }
-#endif
     return rc;
 }
 
+rc_t CC ArgsAddOptionArray (Args * self, const OptDef * options, uint32_t count
+    /*, rc_t (*header_fmt)(Args * args, const char * header), const char * header */ )
+{
+    return ArgsAddOptionArray_int(self, false, count, options);
+}
+
 rc_t CC ArgsAddParam ( Args * self, const ParamDef * param_def )
 {
     rc_t rc;
     Parameter * param;
     uint32_t params_count;
-    
+
     assert(self);
     assert(param_def);
-    
+
     params_count = VectorLength(&self->params);
-    
+
     rc = ParamMake (&param, params_count, param_def->convert_fn);
     if (rc)
         return rc;
-    
+
     rc = VectorAppend(&self->params, NULL, param);
     if (rc != 0)
     {
         ParamWhack(param);
     }
-    
+
     return rc;
 }
 
@@ -1029,12 +991,12 @@ rc_t CC ArgsAddLongParam ( Args * self, const char * param_name, const char * he
 rc_t CC ArgsAddParamArray (Args * self, const ParamDef * param, uint32_t count)
 {
     rc_t rc;
-    
+
     for (rc = 0; (rc == 0) && (count > 0); --count, ++param)
     {
         rc = ArgsAddParam (self, param);
     }
-    
+
     return 0;
 }
 
@@ -1101,25 +1063,25 @@ static
 rc_t CC ProcessArgConversion(Args * self, ParamValueContainer * p_container)
 {
     rc_t rc = 0;
-    
+
     assert(p_container);
-    
+
     if (p_container->convert_fn)
     {
         char * param_value = (char *)p_container->param_value;
         WhackParamFnP whack = p_container->whack;
-        
+
         p_container->param_value = NULL;
         p_container->whack = NULL;
         rc = p_container->convert_fn(self, p_container->param_index, param_value, string_size(param_value), &p_container->param_value, &p_container->whack);
         whack(param_value);
-        
+
         if (rc == 0 && p_container->whack == NULL)
         {
             p_container->whack = ParamValueNotConvWhack;
         }
     }
-    
+
     return rc;
 }
 
@@ -1129,7 +1091,7 @@ rc_t CC ProcessArgsConversion(Args * self)
     rc_t rc = 0;
     uint32_t i, param_count = VectorLength(&self->param_values);
     ParamValueContainer * p_container;
-    
+
     for (i = 0; i < param_count; ++i)
     {
         p_container = VectorGet (&self->param_values, i);
@@ -1137,7 +1099,7 @@ rc_t CC ProcessArgsConversion(Args * self)
         if (rc != 0)
             break;
     }
-    
+
     if (rc == 0)
     {
         BSTNode* node = BSTreeFirst(&self->names);
@@ -1154,17 +1116,17 @@ rc_t CC ProcessArgsConversion(Args * self)
                     if (rc != 0)
                         break;
                 }
-                
+
                 if (rc != 0)
                     break;
             }
-            
+
             node = BSTNodeNext(node);
         }
     }
-    
+
     return rc;
-    
+
 }
 
 static
@@ -1178,7 +1140,7 @@ rc_t ArgsParseInt (Args * self, int argc, char *argv[])
     Option * node;
     const char * parg;
     char * equal_sign;
-    
+
     char name [32];
     const char * value = NULL;
     size_t value_len;
@@ -1195,7 +1157,7 @@ rc_t ArgsParseInt (Args * self, int argc, char *argv[])
 
         parg = argv[ix];
         len = string_size ( parg );
-        
+
         p_container = (ParamValueContainer *)malloc( sizeof *p_container );
         if (p_container == NULL)
         {
@@ -1215,7 +1177,7 @@ rc_t ArgsParseInt (Args * self, int argc, char *argv[])
         else
             ARGS_DBG( "ArgsParse: inserted '%s' into self->argv", parg );
     }
-    
+
     if ( rc )
         return rc;
 
@@ -1336,7 +1298,7 @@ rc_t ArgsParseInt (Args * self, int argc, char *argv[])
                     OptAlias *alias;
                     uint32_t c;
 
-                    name_len = utf8_utf32( &c, parg + jx, end ); 
+                    name_len = utf8_utf32( &c, parg + jx, end );
                     string_copy( name, sizeof( name ), parg + jx, name_len );
 
                     alias = ( OptAlias* )BSTreeFind( &self->aliases, name, OptAliasCmp );
@@ -1464,7 +1426,7 @@ rc_t ArgsParseInt (Args * self, int argc, char *argv[])
         if ( rc )
             break;
     }
-    
+
     if (rc == 0)
     {
         rc = ProcessArgsConversion(self);
@@ -1502,7 +1464,7 @@ rc_t ArgsParseInt (Args * self, int argc, char *argv[])
     return rc;
 }
 
-rc_t CC ArgsParse (Args * self, int argc, char *argv[])
+rc_t CC ArgsParse_int (Args * self, int argc, char *argv[])
 {
     KLogLevel lvl = KLogLevelGet ();
     rc_t rc = KLogLevelSet ( klogWarn );
@@ -1511,6 +1473,17 @@ rc_t CC ArgsParse (Args * self, int argc, char *argv[])
     return rc;
 }
 
+/** Process `argv` using the options that have been defined. */
+rc_t CC ArgsParse (Args * self, int argc, char *argv[])
+{
+    /*
+     This function is called AFTER all options have been defined,
+     so this is where we want to close the option definitions log.
+     */
+    closeOptionDefs();
+    return ArgsParse_int(self, argc, argv);
+}
+
 rc_t CC ArgsOptionCount (const Args * self, const char * option_name, uint32_t * count)
 {
     rc_t rc;
@@ -1558,7 +1531,7 @@ rc_t CC ArgsOptionValueExt (const Args * self, const char * option_name,
     node = (const Option*)BSTreeFind (&self->names, option_name, OptionCmp);
     if (node == NULL)
         return RC (rcExe, rcArgv, rcAccessing, rcName, rcNotFound);
-    
+
     rc = OptionGetValue (node, iteration, value_bin);
 
     * called_as_alias = node -> called_by_alias;
@@ -1587,7 +1560,7 @@ rc_t CC ArgsParamCount (const Args * self, uint32_t * count)
 rc_t CC ArgsParamValue (const Args * self, uint32_t iteration, const void ** value)
 {
     rc_t rc;
-    
+
     if (self == NULL)
         return RC (rcExe, rcArgv, rcAccessing, rcSelf, rcNull);
 
@@ -1600,7 +1573,7 @@ rc_t CC ArgsParamValue (const Args * self, uint32_t iteration, const void ** val
         return RC (rcExe, rcArgv, rcAccessing, rcParam, rcExcessive);
     }
 
-    
+
     rc = ParamGetValue (&self->param_values, iteration, value);
     return rc;
 }
@@ -1627,7 +1600,7 @@ rc_t CC ArgsArgc (const Args * self, uint32_t * count)
 rc_t CC ArgsArgvValue (const Args * self, uint32_t iteration, const char ** value_string)
 {
     ParamValueContainer * p_container;
-    
+
     if (self == NULL)
         return RC (rcExe, rcArgv, rcAccessing, rcSelf, rcNull);
 
@@ -1642,46 +1615,46 @@ rc_t CC ArgsArgvValue (const Args * self, uint32_t iteration, const char ** valu
 
     p_container = (ParamValueContainer*) VectorGet (&self->argv, iteration);
     assert(p_container);
-    
+
     *value_string = (const char *)p_container->param_value;
     return 0;
 }
 
 #define USAGE_MAX_SIZE 81
 static
-const char * verbose_usage[] = 
+const char * verbose_usage[] =
 { "Increase the verbosity of the program status messages.",
   "Use multiple times for more verbosity.","Negates quiet.", NULL };
 static
-const char * quiet_usage[] = 
+const char * quiet_usage[] =
 { "Turn off all status messages for the program.",
   "Negated by verbose.", NULL };
 static
-const char * debug_usage[] = 
+const char * debug_usage[] =
 { "Turn on debug output for module.",
   "All flags if not specified.", NULL };
 static
-const char * help_usage[] = 
+const char * help_usage[] =
 { "Output a brief explanation for the program.", NULL };
 static
-const char * report_usage[] = 
+const char * report_usage[] =
 { "Control program execution environment report generation (if implemented).",
     "One of (never|error|always). Default is error.", NULL };
 static
-const char * version_usage[] = 
+const char * version_usage[] =
 { "Display the version of the program then quit.", NULL };
 static
-const char * optfile_usage[] = 
+const char * optfile_usage[] =
 { "Read more options and parameters from the file.", NULL};
-static 
+static
 char log0 [USAGE_MAX_SIZE];
-static 
+static
 char log1 [USAGE_MAX_SIZE];
 static
-const char * log_usage[] = 
+const char * log_usage[] =
 { "Logging level as number or enum string.", log0, log1, NULL };
 static
-const char * no_user_settings_usage[] = 
+const char * no_user_settings_usage[] =
 { "Turn off user-specific configuration.", NULL };
 
     /*  We need dat here
@@ -1736,7 +1709,7 @@ void CC gen_log_usage (const char ** _buffers)
         pc -= sizeof div - 1;
         rem += sizeof div - 1;
         *pc = '\0';
-        
+
         rc = string_printf (p0, USAGE_MAX_SIZE, & used,
                             "One of (%s) or (%u-%u)",
                             buffv, klogLevelMin, klogLevelMax);
@@ -1793,7 +1766,7 @@ OptDef StandardOptions[]  =
     },
 #endif
     {
-        OPTION_DEBUG           , ALIAS_DEBUG    , NULL, debug_usage, 
+        OPTION_DEBUG           , ALIAS_DEBUG    , NULL, debug_usage,
         OPT_UNLIM, true , false
     },
     {
@@ -1801,24 +1774,24 @@ OptDef StandardOptions[]  =
         OPT_UNLIM, false, false
     },
     {   /* OPTION_REPORT is used in klib/report.c */
-        OPTION_REPORT          , NULL           , NULL, report_usage, 
+        OPTION_REPORT          , NULL           , NULL, report_usage,
         OPT_UNLIM, true , false
     }
 };
 
 rc_t CC ArgsAddStandardOptions(Args * self)
 {
-    return ArgsAddOptionArray (self, StandardOptions,
-                               sizeof (StandardOptions) / sizeof (OptDef)
-                               /*, NULL, NULL */ );
+    return ArgsAddOptionArray_int (self, true,
+                                   sizeof (StandardOptions) / sizeof (OptDef)
+                                   , StandardOptions );
 }
 
-rc_t CC ArgsMakeStandardOptions (Args** pself)
+static rc_t ArgsMakeStandardOptions_int(Args** pself, char const *const argv0)
 {
     Args * self;
     rc_t rc;
 
-    rc = ArgsMake (&self);
+    rc = ArgsMake_int(&self, argv0);
     if (rc == 0)
     {
         rc = ArgsAddStandardOptions (self);
@@ -1829,6 +1802,11 @@ rc_t CC ArgsMakeStandardOptions (Args** pself)
     return rc;
 }
 
+rc_t CC ArgsMakeStandardOptions (Args** pself)
+{
+    return ArgsMakeStandardOptions_int(pself, NULL);
+}
+
 rc_t CC ArgsHandleHelp (Args * self)
 {
     uint32_t count;
@@ -2025,7 +2003,7 @@ rc_t CC ArgsHandleStandardOptions (Args * self)
         if (rc != 0)
             break;
 
-#if _DEBUGGING 
+#if _DEBUGGING
 	/* called a second time in case more symbols in in files */
         rc = ArgsHandleDebug (self);
         if (rc != 0)
@@ -2049,7 +2027,7 @@ rc_t ArgsMakeAndHandleInt ( Args ** pself, int argc, char ** argv,
         * pself = NULL;
     }
 
-    rc = ArgsMakeStandardOptions (&self);
+    rc = ArgsMakeStandardOptions_int(&self, argv[0]);
     if ( rc == 0 && param_count != 0 )
     {
         if ( params == NULL )
@@ -2119,7 +2097,7 @@ rc_t ArgsMakeAndHandleInt ( Args ** pself, int argc, char ** argv,
 
             break;
         }
-    
+
         ArgsWhack (self);
     }
     return rc;
@@ -2182,7 +2160,7 @@ rc_t CC ArgsProgram (const Args * args, const char ** fullpath, const char ** pr
     else
     {
         f = defaultname;
-        
+
         if (fullpath != NULL)
         {
             if (*fullpath == NULL)
@@ -2336,7 +2314,7 @@ void CC HelpParamLine (const char * param, const char * const * msgs)
     const char * msg;
 
     msg = *msgs++;
-    
+
     if (param)
     {
         OUTMSG (("%*s%s%n", INDENT, " ", param, &msgc));
@@ -2372,7 +2350,7 @@ void CC HelpOptionsStandard(void){
     HelpOptionLine(ALIAS_OPTFILE  ,OPTION_OPTFILE  , "file"  , optfile_usage);
 #endif
 #if _DEBUGGING
-    HelpOptionLine(ALIAS_DEBUG    ,OPTION_DEBUG, "Module[-Flag]", debug_usage); 
+    HelpOptionLine(ALIAS_DEBUG    ,OPTION_DEBUG, "Module[-Flag]", debug_usage);
         /* Dat is spooky place, we will print 'standard' append mode
          * help only it is necessary and only in debugging mode
          */
