@@ -30,10 +30,6 @@
 #include "kdbfmt-priv.h"
 #include "dbmgr-priv.h"
 
-#include <krypto/key.h>
-#include <krypto/encfile.h>
-#include <krypto/wgaencrypt.h>
-
 #include <vfs/manager.h>
 #include <vfs/path.h>
 #include <vfs/resolver.h>
@@ -656,7 +652,7 @@ static rc_t KDBOpenPathTypeReadInt ( const KDBManager * mgr, const KDirectory *
                         KDirectoryRelease( ldir );
                 }
             }
-            if ( aVpath == NULL )
+            if ( aVpath != vpath )
                 VPathRelease ( vpath );
         }
     }
