@@ -2140,3 +2140,157 @@ LIB_EXPORT rc_t CC KMDataNodeListChildren ( const KMDataNode *self, KNamelist **
 
     return RC ( rcDB, rcMetadata, rcListing, rcSelf, rcNull );
 }
+
+/*--------------------------------------------------------------------------
+ * deep comparison of 2 Metadata-nodes
+ */
+
+/* >>>>>> !!! any changes here have to be duplicated in wmeta.c !!! <<<<<< */
+static rc_t KMDataNodeCompare_int( const KMDataNode *self, const KMDataNode *other, bool *equal );
+
+/* >>>>>> !!! any changes here have to be duplicated in wmeta.c !!! <<<<<< */
+static rc_t KMDataNodeCompareValue( const KMDataNode *self, const KMDataNode *other, bool *equal ) {
+    void const *self_data = NULL;
+    size_t self_size = 0;
+    rc_t rc = KMDataNodeAddr( self, &self_data, &self_size );
+    if ( 0 == rc ) {
+        void const *other_data = NULL;
+        size_t other_size = 0;
+        rc = KMDataNodeAddr( other, &other_data, &other_size );
+        if ( 0 == rc ) {
+            if ( self_size != other_size ) {
+                *equal = false; /* if the sizes are different - they can't be equal... */
+            } else if ( 0 == self_size ) {
+                *equal = true; /* if both nodes have no data... */                
+            } else {
+                int cmp = memcmp( self_data, other_data, self_size );
+                *equal = ( 0 == cmp );
+            }
+        }
+    }
+    return rc;
+}
+
+/* >>>>>> !!! any changes here have to be duplicated in wmeta.c !!! <<<<<< */
+struct CompareContext {
+    KMDataNode const *other;
+    bool *equal;
+    rc_t rc;
+};
+
+/* >>>>>> !!! any changes here have to be duplicated in wmeta.c !!! <<<<<< */
+static void CC KMDataNodeCompareChildren_cb( BSTNode *n, void *data ) {
+    struct CompareContext *const ctx = data;
+    if ( 0 == ctx -> rc && *( ctx -> equal ) ) {
+        const KMDataNode *child = ( const KMDataNode * )n;
+        const char * childName = child -> name;
+        // find the corresponding child-node in ctx -> other
+        const KMDataNode *other_child;
+        ctx -> rc = KMDataNodeOpenNodeRead( ctx -> other, &other_child, childName );
+        if ( 0 == ctx -> rc ) {
+            ctx -> rc = KMDataNodeCompare_int( child, other_child, ctx -> equal ); /* recursion here! */
+        } else {
+            *( ctx -> equal ) = false;
+        }
+    }
+}
+
+/* >>>>>> !!! any changes here have to be duplicated in wmeta.c !!! <<<<<< */
+static void CC KMDataNodeCompareAttr_cb( BSTNode *n, void *data ) {
+    struct CompareContext *const ctx = data;
+    if ( 0 == ctx -> rc && *( ctx -> equal ) ) {
+        const KMAttrNode *attr = ( const KMAttrNode * )n;
+        if ( NULL != attr ) {
+            const char * attrName = attr -> name;
+            const KMAttrNode *other_attr = ( const KMAttrNode* )BSTreeFind( &( ctx -> other -> attr ),
+                                                                            attrName, KMAttrNodeCmp );
+            if ( NULL == other_attr ) {
+                *( ctx -> equal ) = false; /* not found in other... */
+            } else if ( attr -> vsize != other_attr -> vsize ) {
+                *( ctx -> equal ) = false; /* if the sizes are different - they can't be equal... */
+            } else if ( 0 == attr -> vsize ) {
+                *( ctx -> equal ) = true; /* both attributes have no data... */
+            } else {
+                int cmp = memcmp( attr -> value, other_attr -> value, attr -> vsize );
+                *( ctx -> equal ) = ( 0 == cmp );
+            }
+        }
+    }
+}
+
+/* >>>>>> !!! any changes here have to be duplicated in wmeta.c !!! <<<<<< */
+static rc_t KMDataNodeCompare_int( const KMDataNode *self, const KMDataNode *other, bool *equal ) {
+    /* first we compare the value of these 2 nodes */
+    rc_t rc = KMDataNodeCompareValue( self, other, equal );
+    if ( 0 == rc && *equal ) {
+        /* if they are equal, we compare all of the children of self with the children of other */
+        struct CompareContext ctx = { other, equal, 0 };
+        BSTreeForEach( &( self -> child ), false, KMDataNodeCompareChildren_cb, &ctx );
+        rc = ctx . rc;
+        if ( 0 == rc && *equal ) {
+            /* if they are equal we compare all attributes... */
+            BSTreeForEach( &( self -> attr ), false, KMDataNodeCompareAttr_cb, &ctx );
+            rc = ctx .rc;
+        }
+    }
+    return rc;
+}
+
+/* >>>>>> !!! any changes here have to be duplicated in wmeta.c !!! <<<<<< */
+LIB_EXPORT rc_t CC KMDataNodeCompare( const KMDataNode *self, KMDataNode const *other, bool *equal ) {
+    rc_t rc = 0;
+    if ( self == NULL ) { 
+        rc = RC( rcDB, rcNode, rcComparing, rcSelf, rcNull );
+    } else if ( other == NULL || equal == NULL ) { 
+        rc = RC( rcDB, rcNode, rcComparing, rcParam, rcNull );
+    } else if ( self -> meta == NULL && other -> meta == NULL ) {
+        *equal = true;
+    } else if ( self -> meta == NULL || other -> meta == NULL ) {
+        *equal = false;
+        rc = RC( rcDB, rcNode, rcComparing, rcMetadata, rcNull );
+    } else {
+        /* 2 way comparison, to make sure that both nodes have the same children... */
+        rc =  KMDataNodeCompare_int( self, other, equal );
+        if ( 0 == rc && *equal ) {
+            rc =  KMDataNodeCompare_int( other, self, equal );            
+        }
+    }
+    return rc;
+}
+
+/* KTableMetaCompare
+ *  test if 2 tables have the same MetaDataNode ( and content ) for a given path
+ */
+/* >>>>>> !!! any changes here have to be duplicated in wmeta.c !!! <<<<<< */
+LIB_EXPORT rc_t CC KTableMetaCompare( const KTable *self, const KTable *other,
+                                      const char * path, bool * equal ) {
+    rc_t rc = 0;
+    if ( NULL == self ) {
+        rc = RC ( rcDB, rcTable, rcComparing, rcSelf, rcNull );
+    } else if ( NULL == other || NULL == path || NULL == equal ) {
+        rc = RC ( rcDB, rcTable, rcComparing, rcParam, rcNull );        
+    } else {
+        const KMetadata *self_meta;
+        rc = KTableOpenMetadataRead( self, &self_meta );
+        if ( 0 == rc ) {
+            const KMetadata *other_meta;
+            rc = KTableOpenMetadataRead( other, &other_meta );
+            if ( 0 == rc ) {
+                const KMDataNode * self_node;
+                rc = KMetadataOpenNodeRead( self_meta, &self_node, path );
+                if ( 0 == rc ) {
+                    const KMDataNode * other_node;
+                    rc = KMetadataOpenNodeRead( other_meta, &other_node, path );
+                    if ( 0 == rc ) {
+                        rc = KMDataNodeCompare( self_node, other_node, equal );
+                        KMDataNodeRelease( other_node );
+                    }
+                    KMDataNodeRelease( self_node );
+                }
+                KMetadataRelease( other_meta );                
+            }
+            KMetadataRelease( self_meta );
+        }
+    }
+    return rc;
+}
