@@ -55,6 +55,11 @@
 /* keep file system structure compatible with v0 code */
 #define V0_BACKWARD_COMPAT 0
 
+/*--------------------------------------------------------------------------
+ * turns ON verbose REFCOUNT tracing
+ */
+#define REPORT_KTABLE_REFCOUNT 0
+
 /*--------------------------------------------------------------------------
  * KTable
  *  a collection of columns indexed by row id, metadata, indices
@@ -124,6 +129,9 @@ rc_t KTableWhack ( KTable *self )
     return rc;
 }
 
+#if REPORT_KTABLE_REFCOUNT
+void KTableGetName( KTable const *self, char const **rslt );
+#endif
 
 /* AddRef
  * Release
@@ -135,7 +143,18 @@ LIB_EXPORT rc_t CC KTableAddRef ( const KTable *cself )
     KTable *self = ( KTable* ) cself;
     if ( self != NULL )
     {
-        switch ( KRefcountAdd ( & self -> refcount, "KTable" ) )
+#if REPORT_KTABLE_REFCOUNT
+        uint32_t before = atomic32_read( &self -> refcount );
+#endif
+        int ret = KRefcountAdd ( & self -> refcount, "KTable" );
+#if REPORT_KTABLE_REFCOUNT
+        uint32_t after = atomic32_read( &self -> refcount );
+        char const * name;
+        KTableGetName( self, &name );
+        KDbgMsg( "KTableAddRef( %p %s ) %x ---> %x\n", self, name, before, after );
+#endif
+
+        switch ( ret )
         {
         case krefLimit:
             return RC ( rcDB, rcTable, rcAttaching, rcRange, rcExcessive );
@@ -150,7 +169,18 @@ LIB_EXPORT rc_t CC KTableRelease ( const KTable *cself )
     KTable *self = ( KTable* ) cself;
     if ( self != NULL )
     {
-        switch ( KRefcountDrop ( & self -> refcount, "KTable" ) )
+#if REPORT_KTABLE_REFCOUNT
+        uint32_t before = atomic32_read( &self -> refcount );
+#endif
+        int ret = KRefcountDrop ( & self -> refcount, "KTable" );
+#if REPORT_KTABLE_REFCOUNT
+        uint32_t after = atomic32_read( &self -> refcount );
+        char const * name;
+        KTableGetName( self, &name );
+        KDbgMsg( "KTableRelease( %p %s ) %x ---> %x\n", self, name, before, after );
+#endif
+
+        switch ( ret )
         {
         case krefWhack:
             return KTableWhack ( ( KTable* ) self );
@@ -170,7 +200,18 @@ KTable *KTableAttach ( const KTable *self )
 {
     if ( self != NULL )
     {
-        switch ( KRefcountAddDep ( & self -> refcount, "KTable" ) )
+#if REPORT_KTABLE_REFCOUNT
+        uint32_t before = atomic32_read( &self -> refcount );
+#endif
+        int ret = KRefcountAddDep ( & self -> refcount, "KTable" );
+#if REPORT_KTABLE_REFCOUNT
+        uint32_t after = atomic32_read( &self -> refcount );
+        char const * name;
+        KTableGetName( self, &name );
+        KDbgMsg( "KTableAttach( %p %s ) %x ---> %x\n", self, name, before, after );
+#endif
+
+        switch ( ret )
         {
         case krefLimit:
             return NULL;
@@ -187,7 +228,18 @@ rc_t KTableSever ( const KTable *self )
 {
     if ( self != NULL )
     {
-        switch ( KRefcountDropDep ( & self -> refcount, "KTable" ) )
+#if REPORT_KTABLE_REFCOUNT
+        uint32_t before = atomic32_read( &self -> refcount );
+#endif
+        int ret = KRefcountDropDep ( & self -> refcount, "KTable" );
+#if REPORT_KTABLE_REFCOUNT
+        uint32_t after = atomic32_read( &self -> refcount );
+        char const * name;
+        KTableGetName( self, &name );
+        KDbgMsg( "KTableSever( %p %s ) %x ---> %x\n", self, name, before, after );
+#endif
+
+        switch ( ret )
         {
         case krefWhack:
             assert ( self -> opencount == 0 );
@@ -240,6 +292,15 @@ rc_t KTableMake ( KTable **tblp, const KDirectory *dir, const char *path,
     tbl -> read_only = read_only;
     strcpy ( tbl -> path, path );
 
+#if REPORT_KTABLE_REFCOUNT
+    {
+        uint32_t after = atomic32_read( &tbl -> refcount );
+        char const * name;
+        KTableGetName( tbl, &name );
+        KDbgMsg( "KTableMake( %p %s ) %x\n", tbl, name, after );
+    }
+#endif
+
     tbl->sym.u.obj = tbl;
     StringInitCString (&tbl->sym.name, tbl->path);
     tbl->sym.type = kptTable;
@@ -1728,3 +1789,119 @@ KDB_EXTERN bool CC KTableHasRemoteData ( const KTable *self )
 {
     return true;
 }
+
+/** @brief Copy a column using directory operations
+ */
+static rc_t KTableCopyObject_int(  KTable *self
+                                 , KTable const *source
+                                 , const char *name
+                                 , char const *type)
+{
+    KDirectory *dst = NULL;
+    KDirectory const *src = NULL;
+    rc_t rc;
+
+    rc = KDirectoryOpenDirRead(source->dir, &src, true, "%s", type);
+    if (rc)
+        return rc;
+
+    rc = KDirectoryOpenDirUpdate(self->dir, &dst, true, "%s", type);
+    if (rc == 0) {
+        rc = KDirectoryCopyPaths(src, dst, true, name, name);
+        KDirectoryRelease(dst);
+    }
+    KDirectoryRelease(src);
+    return rc;
+}
+
+/** @brief A good source exists and is not being written to.
+ */
+static rc_t KTableObjectIsGoodSource(KTable const *self
+                                     , char const *name
+                                     , char const *type)
+{
+    char path [ 256 ];
+    rc_t rc = KDBMakeSubPath(self->dir, path, sizeof(path), type, 3, "%s", name);
+    assert(rc == 0);
+    if (rc)
+        return rc;
+
+    rc = KDBWritable(self->dir, path);
+    if (rc == 0) {
+        if (KDBManagerOpenObjectBusy(self->mgr, path))
+            return RC ( rcDB, rcTable, rcCopying, rcPath, rcBusy );
+    }
+    else if (GetRCState(rc) == rcLocked || GetRCState(rc) == rcReadonly)
+        rc = 0;
+    return rc;
+}
+
+/** @brief A good destination does not exist.
+ */
+static rc_t KTableObjectIsGoodDestination(KTable *self
+                                          , char const *name
+                                          , char const *type)
+{
+    char path [ 256 ];
+    rc_t rc = KDBMakeSubPath(self->dir, path, sizeof(path), type, 3, "%s", name);
+    assert(rc == 0);
+    if (rc)
+        return rc;
+
+    rc = KDBWritable(self->dir, path);
+    if (rc == 0)
+        return RC(rcDB, rcTable, rcCopying, rcPath, rcExists);
+    if (GetRCState(rc) == rcLocked || GetRCState(rc) == rcReadonly)
+        return RC(rcDB, rcTable, rcCopying, rcPath, GetRCState(rc));
+    return 0;
+}
+
+static rc_t KTableCopyObject(  KTable *self
+                             , KTable const *source
+                             , char const *name
+                             , char const *type)
+{
+    rc_t rc = KTableObjectIsGoodSource(source, name, type);
+    if (rc)
+        return rc;
+
+    rc = KTableObjectIsGoodDestination(self, name, type);
+    if (rc)
+        return rc;
+
+    return KTableCopyObject_int(self, source, name, type);
+}
+
+LIB_EXPORT rc_t CC KTableCopyColumn(  KTable *self
+                                    , KTable const *source
+                                    , const char *name)
+{
+    rc_t rc = 0;
+
+    if (self == NULL)
+        return RC(rcDB, rcTable, rcCopying, rcSelf, rcNull);
+
+    if (self->read_only)
+        return RC(rcDB, rcTable, rcCopying, rcSelf, rcReadonly);
+
+    rc = KTableCopyObject(self, source, name, "col");
+    if (rc)
+        return RC(rcDB, rcTable, rcCopying, rcColumn, GetRCState(rc));
+    return rc;
+}
+
+LIB_EXPORT rc_t CC KTableCopyIndex(  KTable *self
+                                    , KTable const *source
+                                    , const char *name)
+{
+    rc_t rc = 0;
+
+    if (self == NULL)
+        return RC(rcDB, rcTable, rcCopying, rcSelf, rcNull);
+
+    if (self->read_only)
+        return RC(rcDB, rcTable, rcCopying, rcSelf, rcReadonly);
+
+    rc = KTableCopyObject(self, source, name, "idx");
+    return RC(rcDB, rcTable, rcCopying, rcIndex, GetRCState(rc));
+}
