@@ -140,7 +140,7 @@ void CC KPTrieIndexExtractV1Range_v2 ( PTNode *n, void *data )
     /* capture node id */
     uint32_t id;
     assert ( n -> data . size == sizeof id );
-    memcpy ( & id, n -> data . addr, sizeof id );
+    memmove ( & id, n -> data . addr, sizeof id );
 
     /* perform min/max */
     if ( self -> count == 0 )
@@ -828,7 +828,7 @@ rc_t KPTrieIndexFind_v2 ( const KPTrieIndex_v2 *self,
                 /* v1 stored tree will have just a 32-bit spot id as data */
                 uint32_t id;
                 assert ( pnode . data . size == sizeof id );
-                memcpy ( & id, pnode . data . addr, sizeof id );
+                memmove ( & id, pnode . data . addr, sizeof id );
                 * start_id = id;
                 rc = 0;
             }
@@ -1042,7 +1042,7 @@ rc_t CC KTrieIndexWrite_v2 ( void *param,
 
         if ( to_write > 0 )
         {
-            memcpy ( pb -> buffer + pb -> marker,
+            memmove ( pb -> buffer + pb -> marker,
                 ( const uint8_t* ) buffer + total, to_write );
             pb -> marker += to_write;
         }
@@ -1068,7 +1068,7 @@ rc_t CC KTrieIndexWrite_v2 ( void *param,
             pb -> pos += num_flushed;
 
             if ( pb -> marker != 0 )
-                memcpy ( pb -> buffer, pb -> buffer + num_flushed, pb -> marker );
+                memmove ( pb -> buffer, pb -> buffer + num_flushed, pb -> marker );
         }
     }
 
