@@ -35,7 +35,7 @@
 
 /* from binary 0..63 to standard BASE64 encoding */
 static
-const char encode_std_table [] =
+const signed char encode_std_table [] =
     "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
     "abcdefghijklmnopqrstuvwxyz"
     "0123456789"
@@ -49,7 +49,7 @@ const char encode_std_table [] =
  *   -3 would normally mean ignore
  */
 static
-const char decode_std_table [] =
+const signed char decode_std_table [] =
     "\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff" /* \x00 .. \x0F */
     "\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff" /* \x10 .. \x1F */
     "\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x3e\xff\xff\xff\x3f" /* \x20 .. \x2F */
@@ -70,7 +70,7 @@ const char decode_std_table [] =
 
 /* from binary 0..63 to BASE64-URL encoding */
 static
-const char encode_url_table [] =
+const signed char encode_url_table [] =
     "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
     "abcdefghijklmnopqrstuvwxyz"
     "0123456789"
@@ -84,7 +84,7 @@ const char encode_url_table [] =
  *   -3 would normally mean ignore
  */
 static
-const char decode_url_table [] =
+const signed char decode_url_table [] =
     "\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff" /* \x00 .. \x0F */
     "\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff" /* \x10 .. \x1F */
     "\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x3e\xff\xff" /* \x20 .. \x2F */
@@ -105,11 +105,11 @@ const char decode_url_table [] =
 
 static
 rc_t encodeBase64Impl ( const String ** encoded, const void * data, size_t bytes,
-                        const char encode_table [] )
+                        const signed char encode_table [] )
 {
     char *buff;
     size_t i, j, esize;
-    
+
     /* gather encoded output in a string - this is why we wanted to limit the data size */
     String *encoding;
 
@@ -117,7 +117,7 @@ rc_t encodeBase64Impl ( const String ** encoded, const void * data, size_t bytes
         return RC ( rcRuntime, rcString, rcEncoding, rcParam, rcNull );
 
     * encoded = NULL;
-    
+
     /* allow an empty source */
     if ( bytes == 0 )
     {
@@ -125,11 +125,11 @@ rc_t encodeBase64Impl ( const String ** encoded, const void * data, size_t bytes
         CONST_STRING ( & empty, "" );
         return StringCopy ( encoded, & empty );
     }
-    
+
     /* this exception represents an internal error in any case */
     if ( data == NULL )
         return RC ( rcRuntime, rcString, rcEncoding, rcParam, rcNull );
-    
+
     /* TBD - place an upper limit on data size
      * a very large payload will create a very large string allocation
      * and may indicate garbage that could result in a segfault */
@@ -137,7 +137,7 @@ rc_t encodeBase64Impl ( const String ** encoded, const void * data, size_t bytes
         return RC ( rcRuntime, rcString, rcEncoding, rcData, rcExcessive );
 
     esize = ( ( bytes + 2 ) / 3 ) * 4;
-    
+
     encoding = (String *) malloc ( sizeof *encoding + esize + 1 );
     if ( encoding == NULL )
         return RC ( rcRuntime, rcString, rcEncoding, rcMemory, rcExhausted );
@@ -147,13 +147,13 @@ rc_t encodeBase64Impl ( const String ** encoded, const void * data, size_t bytes
     buff = ( char * ) ( encoding + 1 );
 
     { /* scope trickery */
-        
+
         /* accumulate 24 bits of input at a time into a 32-bit accumulator */
         uint32_t acc;
-        
+
         /* walk across data as a block of octets */
         const unsigned char * js = ( const unsigned char * ) data;
-        
+
         /* consume 3 octets of input while producing 4 output characters */
         for ( i = j = 0; i + 3 <= bytes; i += 3, j += 4 )
         {
@@ -163,7 +163,7 @@ rc_t encodeBase64Impl ( const String ** encoded, const void * data, size_t bytes
                 | ( ( uint32_t ) js [ i + 1 ] <<  8 )
                 | ( ( uint32_t ) js [ i + 2 ] <<  0 )
                 ;
-                        
+
             /* produce the 4 bytes of output through the provided encoding table
              * each index MUST be 0..63 */
             buff [ j + 0 ] = encode_table [ ( acc >> 18 ) & 0x3F ];
@@ -171,7 +171,7 @@ rc_t encodeBase64Impl ( const String ** encoded, const void * data, size_t bytes
             buff [ j + 2 ] = encode_table [ ( acc >>  6 ) & 0x3F ];
             buff [ j + 3 ] = encode_table [ ( acc >>  0 ) & 0x3F ];
         }
-    
+
         /* at this point, the data block is either completely converted
         * or has 1 or 2 bytes left over, since ( bytes % 3 ) is in { 0, 1, 2 }
         * we know "i" is a multiple of 3, and ( bytes - i ) == ( bytes % 3 ) */
@@ -180,23 +180,23 @@ rc_t encodeBase64Impl ( const String ** encoded, const void * data, size_t bytes
         case 0:
             /* everything is complete */
             break;
-            
+
         case 1:
-            
+
             /* 1 octet left over
              * place it in the highest part of 24-bit accumulator */
             acc
                 = ( ( uint32_t ) js [ i + 0 ] << 16 )
                 ;
-                        
+
             /* emit single octet split between two encoding characters */
             buff [ j + 0 ] = encode_table [ ( acc >> 18 ) & 0x3F ];
             buff [ j + 1 ] = encode_table [ ( acc >> 12 ) & 0x3F ];
-            
+
             /* pad the remaining two with padding character */
             buff [ j + 2 ] = '=';
             buff [ j + 3 ] = '=';
-            
+
 #if BASE64_PAD_ENCODING
             /* total number of characters in buffer includes padding */
             j += 4;
@@ -204,26 +204,26 @@ rc_t encodeBase64Impl ( const String ** encoded, const void * data, size_t bytes
             /* total number of characters in buffer does not include padding */
             j += 2;
 #endif
-            
+
             break;
-            
+
         case 2:
-            
+
             /* 2 octets left over
              * place them in the upper part of 24-bit accumulator */
             acc
                 = ( ( uint32_t ) js [ i + 0 ] << 16 )
                 | ( ( uint32_t ) js [ i + 1 ] <<  8 )
                 ;
-                        
+
             /* emit the two octets split across three encoding characters */
             buff [ j + 0 ] = encode_table [ ( acc >> 18 ) & 0x3F ];
             buff [ j + 1 ] = encode_table [ ( acc >> 12 ) & 0x3F ];
             buff [ j + 2 ] = encode_table [ ( acc >>  6 ) & 0x3F ];
-            
+
             /* pad the remainder with padding character */
             buff [ j + 3 ] = '=';
-            
+
 #if BASE64_PAD_ENCODING
             /* total number of characters in buffer includes padding */
             j += 4;
@@ -231,37 +231,37 @@ rc_t encodeBase64Impl ( const String ** encoded, const void * data, size_t bytes
             /* total number of characters in buffer does not include padding */
             j += 3;
 #endif
-            
+
             break;
-            
+
         default:
-        
+
             /* this is theoretically impossible */
             free ( encoding );
             return RC ( rcRuntime, rcString, rcEncoding, rcConstraint, rcViolated );
         }
     }
-        
+
     buff [ j ] = 0;
     StringInit ( encoding, buff, j, ( uint32_t ) j );
-    
+
     /* done. */
     *encoded = encoding;
     return 0;
 }
 
 static
-rc_t decodeBase64Impl ( KDataBuffer *decoded, const String *encoding, const char decode_table [] )
+rc_t decodeBase64Impl ( KDataBuffer *decoded, const String *encoding, const signed char decode_table [] )
 {
     rc_t rc;
-    
+
     /* base the estimate of decoded size on input size
      * this can be over-estimated due to embedded padding or formatting characters */
     size_t i, j, len;
-    
+
     uint32_t acc, ac;
     const unsigned char * en;
-    
+
     /* the returned buffer should be 3/4 the size of the input string,
      * provided that there are no padding bytes in the input */
     size_t bytes;
@@ -273,14 +273,14 @@ rc_t decodeBase64Impl ( KDataBuffer *decoded, const String *encoding, const char
     len = StringSize ( encoding );
     en = ( const unsigned char * ) encoding -> addr;
     bytes = ( ( len + 3 ) / 4 ) * 3;
-    
+
     /* create an output buffer */
     rc = KDataBufferMakeBytes ( decoded, bytes );
     if ( rc != 0 )
         return rc;
-    
+
     buff = (unsigned char *) decoded -> base;
-    
+
     /* walk across the input string a byte at a time
      * avoid temptation to consume 4 bytes at a time,
      * in order to be robust to any allowed stray characters
@@ -290,34 +290,34 @@ rc_t decodeBase64Impl ( KDataBuffer *decoded, const String *encoding, const char
     {
         /* return from table is a SIGNED entity */
         int byte = decode_table [ en [ i ] ];
-        
+
         /* non-negative lookups are valid translations */
         if ( byte >= 0 )
         {
             /* must be 0..63 */
             assert ( byte < 64 );
-            
+
             /* shift 6 bits into accumulator */
             acc <<= 6;
             acc |= byte;
-            
+
             /* if the number of codes in accumulator is 4 ( i.e. 24 bits ) */
             if ( ++ ac == 4 )
-            {                
+            {
                 /* put 3 octets into payload */
                 buff [ j + 0 ] = ( unsigned char ) ( acc >> 16 );
                 buff [ j + 1 ] = ( unsigned char ) ( acc >>  8 );
                 buff [ j + 2 ] = ( unsigned char ) ( acc >>  0 );
-                
+
                 /* clear the accumulator */
                 ac = 0;
-                
+
                 /* keep track of size
                  * NB - this is not YET reflected in payload */
-                 j += 3; 
+                 j += 3;
             }
         }
-        
+
         /* NEGATIVE lookups have to be interpreted */
         else
         {
@@ -325,7 +325,7 @@ rc_t decodeBase64Impl ( KDataBuffer *decoded, const String *encoding, const char
              * which indicates the end of the input */
             if ( byte == -2 )
                 break;
-            
+
             /* the special value -3 would indicate ignore
              * but it's not allowed in JWT and so is not expected to be in table
              * any other value ( notably -1 ) is illegal */
@@ -336,49 +336,49 @@ rc_t decodeBase64Impl ( KDataBuffer *decoded, const String *encoding, const char
             }
         }
     }
-    
+
     /* test the number of 6-bit codes remaining in the accumulator */
     switch ( ac )
     {
     case 0:
         /* none - everything has been converted */
         break;
-        
+
     case 1:
         /* encoding granularity is an octet - 8 bits
          * it MUST be split across two codes - 6 bits each, i.e. 12 bits
          * having only 6 bits in accumulator is illegal */
         KDataBufferWhack ( decoded );
         return RC ( rcRuntime, rcString, rcDecoding, rcConstraint, rcViolated );
-        
+
     case 2:
-        
+
         /* fill accumulator with two padding codes
          * NB - not strictly necessary, but keeps code regular and readable */
         acc <<= 12;
-                
+
         /* set additional octet */
         buff [ j + 0 ] = ( char ) ( acc >> 16 );
-        
+
         /* account for size
          * NB - this is not YET reflected in payload */
         j += 1;
         break;
-        
+
     case 3:
-        
+
         /* fill accumulator with padding */
         acc <<= 6;
-                
+
         /* set additional bytes */
         buff [ j + 0 ] = ( char ) ( acc >> 16 );
         buff [ j + 1 ] = ( char ) ( acc >>  8 );
-        
+
         j += 2;
         break;
-        
+
     default:
-        
+
         /* theoretically impossible */
         KDataBufferWhack ( decoded );
         return RC ( rcRuntime, rcString, rcDecoding, rcConstraint, rcViolated );
