@@ -26,10 +26,10 @@
 #include <arch-impl.h>
 #include <assert.h>
 #include <atomic.h>
-#include <kfs/mmap.h>
 #include <klib/hashfile.h>
 #include <klib/rc.h>
 #include <klib/vector.h>
+#include <kfs/mmap.h>
 #include <kproc/lock.h>
 #include <stdbool.h>
 #include <stdio.h>
@@ -235,8 +235,8 @@ static void hkv_encode( const HKV * in, u8 * out )
     }
     if ( test.key_size != in->key_size )
     {
-        fprintf( stderr, "key_size mismatch %ld %ld\n", test.key_size,
-                 in->key_size );
+        fprintf( stderr, "key_size mismatch %ld %ld\n", (long)test.key_size,
+                 (long)in->key_size );
         abort();
     }
     if ( test.value_size != in->value_size )
