@@ -211,12 +211,13 @@ LIB_EXPORT rc_t CC KConditionTimedWait ( KCondition *self, struct KLock *lock, t
 {
     int status;
 
+    if ( tm == NULL )
+        return KConditionWait ( self, lock );
+
     if ( self == NULL )
         return RC ( rcPS, rcCondition, rcWaiting, rcSelf, rcNull );
     if ( lock == NULL )
         return RC ( rcPS, rcCondition, rcWaiting, rcLock, rcNull );
-    if ( tm == NULL )
-        return RC ( rcPS, rcCondition, rcWaiting, rcTimeout, rcNull );
 
     CMSG ( "%s[%p]: testing timeout structure\n", __func__, self );
     if ( ! tm -> prepared )
