@@ -268,7 +268,7 @@ rc_t FastqReader_Header(const FastqReader* self, bool* label,
     if( self->dad.options & eOrigFormat ) {
         char tmp[1024];
         if( spotname_sz == 0 ) {
-            ret = snprintf(tmp, sizeof(tmp) - 1, "%s.%ld", self->dad.accession, self->dad.spot);
+            ret = snprintf(tmp, sizeof(tmp) - 1, "%s.%lld", self->dad.accession, ( long long int ) self->dad.spot);
             if ( ret < 0 )
                 return RC ( rcSRA, rcString, rcConstructing, rcData, rcCorrupt );
             spotname = tmp;
@@ -284,23 +284,23 @@ rc_t FastqReader_Header(const FastqReader* self, bool* label,
         if( addLabel && readId > 0 ) {
             sep = spotname_sz ? "_" : "";
             if( self->dad.options & ePrintReadId ) {
-                ret = snprintf(buf, maxlen, "%c%s.%ld.%d %.*s%s%.*s length=%d",
-                    prefix, self->dad.accession, self->dad.spot, readId, spotname_sz, spotname, sep, read_label_sz, read_label, read_len);
+                ret = snprintf(buf, maxlen, "%c%s.%lld.%d %.*s%s%.*s length=%d",
+                    prefix, self->dad.accession, ( long long int ) self->dad.spot, readId, spotname_sz, spotname, sep, read_label_sz, read_label, read_len);
             } else {
-                ret = snprintf(buf, maxlen, "%c%s.%ld %.*s%s%.*s length=%d",
-                    prefix, self->dad.accession, self->dad.spot, spotname_sz, spotname, sep, read_label_sz, read_label, read_len);
+                ret = snprintf(buf, maxlen, "%c%s.%lld %.*s%s%.*s length=%d",
+                    prefix, self->dad.accession, ( long long int ) self->dad.spot, spotname_sz, spotname, sep, read_label_sz, read_label, read_len);
             }
         } else if( readId > 0 ) {
             if( self->dad.options & ePrintReadId ) {
-                ret = snprintf(buf, maxlen, "%c%s.%ld.%d %.*s%slength=%d",
-                    prefix, self->dad.accession, self->dad.spot, readId, spotname_sz, spotname, sep, read_len);
+                ret = snprintf(buf, maxlen, "%c%s.%lld.%d %.*s%slength=%d",
+                    prefix, self->dad.accession, ( long long int ) self->dad.spot, readId, spotname_sz, spotname, sep, read_len);
             } else {
-                ret = snprintf(buf, maxlen, "%c%s.%ld %.*s%slength=%d",
-                    prefix, self->dad.accession, self->dad.spot, spotname_sz, spotname, sep, read_len);
+                ret = snprintf(buf, maxlen, "%c%s.%lld %.*s%slength=%d",
+                    prefix, self->dad.accession, ( long long int ) self->dad.spot, spotname_sz, spotname, sep, read_len);
             }
         } else {
-            ret = snprintf(buf, maxlen, "%c%s.%ld %.*s%slength=%u",
-                prefix, self->dad.accession, self->dad.spot, spotname_sz, spotname, sep, spot_len);
+            ret = snprintf(buf, maxlen, "%c%s.%lld %.*s%slength=%u",
+                prefix, self->dad.accession, ( long long int ) self->dad.spot, spotname_sz, spotname, sep, spot_len);
         }
     }
 
@@ -408,13 +408,13 @@ LIB_EXPORT rc_t CC FastqReaderBase(const FastqReader* self, uint32_t readId, cha
     if( me->dad.options & eColorSpace ) {
         const char* b = self->csread->base;
         data[0] = me->csKey == '\0' ? (*self->cs_key)[readId] : me->csKey;
-        memcpy(&data[1], &b[read_start], read_len - 1);
+        memmove(&data[1], &b[read_start], read_len - 1);
         if( read_len > 1 ) {
             rc = FastqReader_CSconvert((*self->cs_key)[readId], data[0], &data[1]);
         }
     } else {
         const char* b = self->read->base;
-        memcpy(data, &b[read_start], read_len);
+        memmove(data, &b[read_start], read_len);
     }
     data[read_len] = '\0';
     return rc;
