@@ -404,7 +404,9 @@ static rc_t VTableCreateCachedCursorReadImpl ( const VTable *self,
 #if DISABLE_READ_CACHE
     capacity = 0;
 #endif
-    if ( cursp == NULL )
+    if ( self == NULL )
+        rc = RC ( rcVDB, rcTable, rcOpening, rcSelf, rcNull );
+    else if ( cursp == NULL )
         rc = RC ( rcVDB, rcTable, rcOpening, rcParam, rcNull );
     else {
         VTableCursor *curs;
@@ -948,7 +950,12 @@ rc_t VCursorOpenRead ( VCURSOR_IMPL *self, const KDlset *libs )
             self -> dad . state = vcReady;
             if( self -> cache_curs )
             {
-                VCursorOpenRead ( ( VTableCursor * ) self -> cache_curs, libs );
+                rc_t const rc2 = VCursorOpenRead ( ( VTableCursor * ) self -> cache_curs, libs );
+                if (rc2) {
+                    LOGERR(klogWarn, rc2, "failed to open cache cursor; not using cache");
+                    VCursorRelease(self->cache_curs);
+                    self->cache_curs = NULL;
+                }
             }
             return rc;
         }
@@ -2249,4 +2256,3 @@ const struct VTable * VTableCursorGetBoundTable( const struct VCURSOR_IMPL * sel
 {
     return NULL;
 }
-
