@@ -36,6 +36,7 @@
 
 #include <vdb/manager.h>
 #include <vdb/database.h>
+#include <vdb/table.h>
 #include <kdb/kdb-priv.h>
 #include <kdb/manager.h>
 #include <kdb/database.h>
@@ -196,7 +197,7 @@ rc_t VDatabaseMake ( VDatabase **dbp,
     rc_t rc;
 
     /* create a structure */
-    VDatabase *db = calloc ( 1, sizeof * db );
+    VDatabase *db = (VDatabase*) calloc ( 1, sizeof * db );
     if ( db == NULL )
         rc = RC ( rcVDB, rcDatabase, rcConstructing, rcMemory, rcExhausted );
     else
@@ -1373,6 +1374,10 @@ LIB_EXPORT bool CC VDatabaseIsCSRA ( const VDatabase *self )
     return false;
 }
 
+/* This function will return true if "file" is recognized
+   as a valid file name for accession "acc".
+   It expect "file" to have extension ".sra" if full-quality is accepted;
+   if zero-quality is accepted: it expects "file" to have extension "xNoqual" */
 static bool validRunFileNameExt(const String * acc, const String * file,
     const String * xNoqual)
 {
@@ -1401,60 +1406,68 @@ static bool validRunFileNameExt(const String * acc, const String * file,
                     return true;
                 }
             }
-            return false;
         }
         else if (quality[j] == 'Z'
               && file->size == acc->size + xNoqual->size)
         {
-            if (string_cmp(file->addr + acc->size, file->size - acc->size,
-                xNoqual->addr, xNoqual->size, xNoqual->size) == 0)
+            if (string_cmp(file->addr, file->size,
+                acc->addr, acc->size, acc->len) == 0)
             {
-                return true;
+                if (string_cmp(file->addr + acc->size, file->size - acc->size,
+                    xNoqual->addr, xNoqual->size, xNoqual->size) == 0)
+                {
+                    return true;
+                }
             }
-            return false;
         }
         else {
             if (string_cmp(file->addr, file->size,
                 acc->addr, acc->size, acc->len) == 0)
             {
+                bool gap = true;
                 const char sfx[] = "_dbGaP-";
                 if (string_cmp(file->addr + acc->size, sizeof sfx - 1,
                     sfx, sizeof sfx - 1, sizeof sfx - 1) == 0)
                 {
+                    bool has = false;
                     size_t i = 0;
                     for (i = acc->size + sizeof sfx - 1;
                         i < file->size; ++i)
                     {
                         char c = file->addr[i];
                         if (c < '0' || c > '9') {
-                            if (c == '.')
-                                break;
-                            else
-                                return false;
+                            if (c != '.' || ! has)
+                                gap = false;
+                            break;
                         }
+                        has = true;
                     }
-                    if (quality[j] == 'R' &&
-                        string_cmp(file->addr + i, file->size - acc->size,
-                                   fullQl, sizeof fullQl - 1, sizeof fullQl - 1
-                                  ) == 0)
-                    {
-                        return true;
-                    }
-                    if (quality[j] == 'Z' &&
-                        string_cmp(file->addr + i, file->size - acc->size,
-                            xNoqual->addr, xNoqual->size, xNoqual->size) == 0)
-                    {
-                        return true;
+                    if (gap) {
+                        if (quality[j] == 'R' &&
+                            string_cmp(file->addr + i, file->size - acc->size,
+                                    fullQl, sizeof fullQl - 1, sizeof fullQl - 1
+                                      ) == 0)
+                        {
+                            return true;
+                        }
+                        if (quality[j] == 'Z' &&
+                            string_cmp(file->addr + i, file->size - acc->size,
+                                    xNoqual->addr, xNoqual->size, xNoqual->size
+                                      ) == 0)
+                        {
+                            return true;
+                        }
                     }
                 }
             }
-            return false;
         }
     }
 
     return false;
 }
 
+/* This function will return true if "file" is recognized
+   as a valid file name for accession "acc": see validRunFileNameExt */
 static bool validRunFileName(const String * acc, const String * file) {
     if (       validRunFileNameExt(acc, file, VFSManagerExtNoqual   (NULL)))
         return true;
@@ -1566,3 +1579,82 @@ LIB_EXPORT rc_t CC VDatabaseSetSynthQualityType ( VDatabase *self )
         return RC ( rcVDB, rcDatabase, rcResetting, rcSelf, rcNull );
     return RC ( rcVDB, rcDatabase, rcResetting, rcMode, rcNotAvailable );
 }
+
+/* VDatabaseMetaCompare
+ *  deep comparison of metadata-nodes between 2 databases...
+ */
+
+static rc_t compare_meta_on_one_table_in_db( const VDatabase *self, const VDatabase *other,
+                                      const char * node_path, const char * tbl_name,
+                                      bool * equal ) {
+    const VTable * tbl1;
+    rc_t rc = VDatabaseOpenTableRead( self, &tbl1, tbl_name );
+    if ( 0 == rc ) {
+        const VTable * tbl2;
+        rc = VDatabaseOpenTableRead( other, &tbl2, tbl_name );
+        if ( 0 == rc ) {
+            rc = VTableMetaCompare( tbl1, tbl2, node_path, equal );
+            VTableRelease( tbl2 );   
+        }
+        VTableRelease( tbl1 );
+    }
+    return rc;
+}
+
+static rc_t compare_meta_on_all_tables_in_db( const VDatabase *self, const VDatabase *other,
+                                      const char * node_path, bool * equal ) {
+    KNamelist * tables_1;
+    rc_t rc = VDatabaseListTbl( self, &tables_1 );
+    if ( 0 == rc ) {
+        KNamelist * tables_2;
+        rc = VDatabaseListTbl( other, &tables_2 );
+        if ( 0 == rc ) {
+            uint32_t count;
+            rc = KNamelistCount( tables_1, &count );
+            if ( 0 == rc ) {
+                uint32_t idx;
+                for ( idx = 0; 0 == rc && idx < count; ++idx ) { 
+                    const char * tbl_name;
+                    rc = KNamelistGet( tables_1, idx, &tbl_name );
+                    if ( 0 == rc ) {
+                        if ( KNamelistContains( tables_2, tbl_name ) ) {
+                            rc = compare_meta_on_one_table_in_db( self, other, node_path, tbl_name, equal );
+                        }
+                    }
+                }
+            }
+            KNamelistRelease( tables_2 );
+        }
+        KNamelistRelease( tables_1 );
+    }
+    return rc;
+}
+
+static bool is_empty( const char * s ) {
+    bool res = ( NULL == s );
+    if ( !res ) { res = ( 0 == s[ 0 ] ); }
+    return res;
+}
+
+LIB_EXPORT rc_t CC VDatabaseMetaCompare( const VDatabase *self, const VDatabase *other,
+                                         const char * node_path, const char * tbl_name,
+                                         bool * equal ) {
+    rc_t rc = 0;
+    if ( NULL == self ) {
+        rc = RC ( rcVDB, rcDatabase, rcComparing, rcSelf, rcNull );
+    } else if ( NULL == other || NULL == equal ) {
+        rc = RC ( rcVDB, rcDatabase, rcComparing, rcParam, rcNull );
+    } else {
+        if ( is_empty( tbl_name ) ) {
+            rc = compare_meta_on_all_tables_in_db( self, other, node_path, equal );
+            if ( 0 == rc && *equal ) {
+                /* one more time with swapped self/other to catch the case where one table
+                   has the node and the other does not */
+                rc = compare_meta_on_all_tables_in_db( other, self, node_path, equal );
+            }
+        } else {
+            rc = compare_meta_on_one_table_in_db( self, other, node_path, tbl_name, equal );
+        }
+    }
+    return rc;
+}
