@@ -20,7 +20,7 @@
 *
 *  Please cite the author in any work or product based on this material.
 *
-* ===========================================================================
+* =============================================================================$
 *
 */
 
@@ -72,6 +72,8 @@
 #define DEBUG_PRINT(fmt, ...) fprintf(stderr, "%s - " fmt "\n", __func__, __VA_ARGS__)
 #endif
 
+static String * s_LoadedQuality = NULL; /* default or from configuration*/
+
 /*--------------------------------------------------------------------------
  * VDBManager
  *  opaque handle to library
@@ -99,6 +101,10 @@ rc_t VDBManagerWhack ( VDBManager *self )
 
         VSchemaRelease ( self -> schema );
         VLinkerRelease ( self -> linker );
+	
+        StringWhack ( s_LoadedQuality );
+        s_LoadedQuality = NULL;
+	
         free ( self );
         return 0;
     }
@@ -225,6 +231,11 @@ LIB_EXPORT rc_t CC VDBManagerAddSchemaIncludePath ( const VDBManager *self, cons
     return rc;
 }
 
+static rc_t VDBManagerAddSchemaIncludePaths(const VDBManager *self, size_t length, const char *paths)
+{
+    return VSchemaAddIncludePaths(self->schema, length, paths);
+}
+
 
 /* AddLoadLibraryPath
  *  add a path[s] to loader for locating dynamic libraries
@@ -330,35 +341,7 @@ rc_t VDBManagerConfigFromKfg ( VDBManager *self, bool update )
             rc = 0;
         else
         {
-            /* split by ':' */
-            const char * path = full;
-            const char *colon = string_chr ( full, num_read, ':' );
-            while ( colon != NULL )
-            {
-                /* add path between "path" and "colon" */
-                rc = VDBManagerAddSchemaIncludePath ( self, "%.*s", ( int ) ( colon - path ), path );
-                if ( rc != 0 )
-                {
-                    PLOGERR ( klogWarn, ( klogWarn, rc, "schema path '$(path)' was rejected",
-                                          "path=%.*s", ( int ) ( colon - path ), path ) );
-                    rc = 0;
-                }
-                num_read -= colon - path + 1;
-                path = colon + 1;
-                colon = string_chr ( path, num_read, ':' );
-            }
-
-            /* add in last portion */
-            if ( rc == 0 && num_read != 0 )
-            {
-                rc = VDBManagerAddSchemaIncludePath ( self, "%.*s", ( int ) ( num_read ), path );
-                if ( rc != 0 )
-                {
-                    PLOGERR ( klogWarn, ( klogWarn, rc, "schema path '$(path)' was rejected",
-                                          "path=%.*s", ( int ) num_read, path ) );
-                    rc = 0;
-                }
-            }
+            rc = VDBManagerAddSchemaIncludePaths(self, num_read, full);
         }
 
         KConfigRelease ( kfg );
@@ -981,7 +964,6 @@ LIB_EXPORT rc_t CC VDBManagerDeleteCacheOlderThan ( const VDBManager * self,
 static const char * s_EnvQuality = NULL; /* from environment */
 static bool s_EnvQualitySet = false;     /* set via environment */
 
-static String * s_LoadedQuality = NULL; /* default or from configuration*/
 static const char * s_SetQuality = NULL;/* explicitly set VDBManagerSetQuality*/
 
 static String s_DfltQuality;
@@ -989,7 +971,7 @@ static String s_DfltQuality;
 static char s_FullQuality[99];
 static char s_ZeroQuality[99];
 
-static rc_t CC VDBManagerSetQuality(VDBManager * self,
+rc_t CC VDBManagerSetQualityString(VDBManager * self,
     const char * quality)
 {
     s_SetQuality = quality;
@@ -1015,6 +997,7 @@ static const char * VDBManagerGetQuality(const VDBManager * self) {
 
     if (s_LoadedQuality == NULL) {
         const KConfig * kfg = NULL;
+
         if (self != NULL) {
             const KDBManager * kmgr = NULL;
             VFSManager * vfs = NULL;
@@ -1026,11 +1009,14 @@ static const char * VDBManagerGetQuality(const VDBManager * self) {
             VFSManagerRelease(vfs);
             KDBManagerRelease(kmgr);
         }
+
         if (kfg == NULL)
             KConfigMake((KConfig**)&kfg, NULL);
+
         rc = KConfigReadString(kfg, "/libs/vdb/quality", &s_LoadedQuality);
         if (rc != 0)
-            s_LoadedQuality = &s_DfltQuality;
+            StringCopy((const String**)&s_LoadedQuality, &s_DfltQuality);
+
         KConfigRelease(kfg);
     }
 
@@ -1092,11 +1078,11 @@ LIB_EXPORT rc_t CC VDBManagerGetQualityString(const VDBManager * self,
 LIB_EXPORT rc_t CC VDBManagerPreferFullQuality(VDBManager * self) {
     const char * quality = VDBManagerGetQuality(self);
     fillPrefQual(quality);
-    return VDBManagerSetQuality(self, s_FullQuality);
+    return VDBManagerSetQualityString(self, s_FullQuality);
 }
 
 LIB_EXPORT rc_t CC VDBManagerPreferZeroQuality(VDBManager * self) {
     const char * quality = VDBManagerGetQuality(self);
     fillPrefQual(quality);
-    return VDBManagerSetQuality(self, s_ZeroQuality);
+    return VDBManagerSetQualityString(self, s_ZeroQuality);
 }
