@@ -1,36 +1,29 @@
 TOP=$1
+CIPHER_DIR=${TOP}/libs/cipher/cipher-1.7
+VIRTUALENV=$(which virtualenv)
 
-if [ $(uname) = "Darwin" ]; then
-    echo "cipher test is turned off on Mac"
+if [ "${PYTHON}" = "" ]; then
+    echo "skipping python cipher test: PYTHON not defined"
+    exit 0
+fi
+if [ "${VIRTUALENV}" = "" ]; then
+    echo "skipping python cipher test: no virtualenv"
     exit 0
 fi
 
 #installing cipher module into newly created virtual env
 tmp_py_env=$(pwd)/temp_env
 
-#just for debugging
-#python3:
-#which python3
-#python3 -V
-#echo python2:
-#which python2
-#python2 -V
-#echo python:
-#which python
-
-python -V
-python_bin=$(which python)
-#if [ "$python_bin" = "" ]; then    python_bin=$(which python2) fi
-if [ "$python_bin" = "" ]; then
-    python_bin=$(which python)
-fi
-virtualenv -p $python_bin $tmp_py_env
+${PYTHON} -V
+${VIRTUALENV} -p ${PYTHON} $tmp_py_env
 . $tmp_py_env/bin/activate
-tmp_cur_dir=$(pwd)
-CIPHER_DIR=$TOP/libs/cipher/cipher-1.7
-cd $CIPHER_DIR
+
+#now inside the virtual env, python is ${PYTHON}
+
 # the following creates "build dist .eggs" in $CIPHER_DIR
-$tmp_py_env/bin/python setup.py install
+tmp_cur_dir=$(pwd)
+cd $CIPHER_DIR
+python setup.py install
 cd $tmp_cur_dir
 unset tmp_cur_dir
 
@@ -44,17 +37,19 @@ do
     echo "Hello world $i" >> test.in
 done
 
-python $TOP/libs/cipher/cipher-1.7/encrypt.py --password=password123 test.in test.enc
-python $TOP/libs/cipher/cipher-1.7/decrypt.py --password=password123 test.enc test.out
+python ${CIPHER_DIR}/encrypt.py --password=password123 test.in test.enc
+python ${CIPHER_DIR}/decrypt.py --password=password123 test.enc test.out
 
 diff test.in test.out
 exit_code=$?
 rm test.in test.enc test.out
 
-echo "pyhon cipher test is complete."
+echo "python cipher test is complete."
 
 # cleanup
 deactivate
+#now outside the virtual env
+
 rm -rf $tmp_py_env
 unset tmp_py_env
 
