@@ -45,8 +45,13 @@
 #include <stdexcept>
 #include <stdint.h>
 #include <stdio.h>
+#ifndef WINDOWS
 #include <sys/time.h>
 #include <unistd.h>
+#else
+#define random rand
+#define srandom srand
+#endif
 #include <unordered_map>
 #include <unordered_set>
 #include <utility>
