@@ -38,6 +38,10 @@
 #include <string.h>
 #include <stdio.h>
 
+#ifdef min
+#undef min
+#endif
+
 size_t min ( size_t a, size_t b )
 {
     return ( a < b ) ? a : b;
