@@ -24,6 +24,7 @@
 *
 */
 
+#include <cmath>
 
 #include "../../libs/vfs/services-priv.h" /* KServiceNames3_0StreamTest */
 #include "../../libs/vfs/path-priv.h" /* VPathEqual */
@@ -358,7 +359,7 @@ TEST_CASE ( BAD_TYPE ) {
     REQUIRE_NULL ( response );
 }
 
-TEST_CASE ( ERROR ) {
+TEST_CASE ( ERROR_ ) {
     const KSrvResponse * response = NULL;
     REQUIRE_RC ( KServiceNames3_0StreamTest ( "#3.0\n"
         "0|| object-id |90|1981-01-13T13:25:30|0123456789abcdefABCDEF012345678c"
@@ -502,6 +503,8 @@ if ( 1 )
 
     REQUIRE_RC ( KServiceRelease ( service ) );
 
+    TEST_MESSAGE("KServiceRelease->KServiceTestNamesExecuteExt");
+
     REQUIRE_RC_FAIL ( KServiceTestNamesExecuteExt ( service, 0, NULL, NULL,
         NULL, NULL ) );
 }
@@ -512,7 +515,9 @@ extern "C" {
     rc_t CC Usage        ( const struct Args * args ) { return 0; }
     ver_t CC KAppVersion ( void ) { return 0; }
     rc_t CC KMain ( int argc, char * argv [] ) {
-        if ( 0 ) assert ( ! KDbgSetString ( "VFS" ) );
+        if ( 
+0 ) assert ( ! KDbgSetString ( "VFS" ) );
+
         KConfigDisableUserSettings ();
 
         rc_t rc = KConfigMake ( & KFG, NULL );
@@ -520,6 +525,9 @@ extern "C" {
             rc = KConfigWriteString ( KFG,
                 "repository/remote/main/CGI/resolver-cgi", RESOLVER_CGI );
 
+        if (
+0) ncbi::NK::TestEnv::SetVerbosity(ncbi::NK::LogLevel::e_all);
+
         rc = Names3_0_TestSuite ( argc, argv );
 
         RELEASE ( KConfig, KFG );
